#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 statistics
version:              0.16.5.0
visibility:           public
id:                   statistics-0.16.5.0-8dDorqU2V6p8ExiapGcyYX
key:                  statistics-0.16.5.0-8dDorqU2V6p8ExiapGcyYX
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/haskell/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
      distributions.  (There are dozens of exotic distributions in use;
      we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
      estimation, histograms, bootstrap methods, significance testing,
      and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
      samples.

category:             Math, Statistics
abi:                  42a7e4140e9655644203aaca02322fc5
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Lognormal
    Statistics.Distribution.NegativeBinomial
    Statistics.Distribution.Normal Statistics.Distribution.Poisson
    Statistics.Distribution.StudentT Statistics.Distribution.Transform
    Statistics.Distribution.Uniform Statistics.Distribution.Weibull
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.Bartlett
    Statistics.Test.ChiSquared Statistics.Test.KolmogorovSmirnov
    Statistics.Test.KruskalWallis Statistics.Test.Levene
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/statistics-0.16.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/statistics-0.16.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/statistics-0.16.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-statistics
hs-libraries:         HSstatistics-0.16.5.0-8dDorqU2V6p8ExiapGcyYX
depends:
    aeson-2.2.2.0-6vy5nFkYOklEBUzF5CRv7u
    async-2.2.6-FyNZXdji95t98VleCj3HXu base-4.18.2.1 binary-0.8.9.1
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc deepseq-1.4.8.1
    dense-linear-algebra-0.1.0.0-6N8dBaCS5drGxc0BujSKw2
    math-functions-0.3.4.4-GO0J15iBVud2eZWlKH90nV
    mwc-random-0.15.3.0-JgIGx1ip5srC1VU2syIxyc
    parallel-3.3.0.0-777lW8EKp7RLYem9SqDKwn
    primitive-0.9.1.0-G6koubL8eviAMsrrurXf06
    random-1.2.1.3-GfiOoTkiJ8dHrTrBUL8yXz
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk
    vector-algorithms-0.9.1.0-KLc09diIeCdBq4aNcp3fNz
    vector-binary-instances-0.2.5.2-3H4vbTQ7A2Z7QA1HIGnLlo
    vector-th-unbox-0.2.2-Fy8lRuCKYbJLnPwRiovsxd

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

